# jxh

Convert JavaScript objects to XML / HTML.

## Install

```sh
npm install jxh
```

## Function Syntax

```js
jxh(obj, indentString, indentLevel);
```
- **obj** : *Required*. Object or array of objects.
- **indentString** : *Optional*. String, basic unit of indentation. Default = 2 spaces.
- **indentLevel** : *Optional*. Number, initial level of indentation. Default = 0.

## Examples

See [GitHub](https://github.com/tnieds/jxh) for full documentation.

### Basic Elements

```js
var obj = {
    div : {
        h1 : 'Heading 1',
        p : ['paragraph1', 'paragraph2', 'paragraph3']
    }
}
var html = jxh(obj);
console.log(html);
```
Output:
```
<div>
  <h1>Heading 1</h1>
  <p>paragraph1</p>
  <p>paragraph2</p>
  <p>paragraph3</p>
</div>
```

### Attributes

```js
var obj = {
        div : {
            _id : 'main-content',
            _class : 'box-top',

            h1 : {
                _class : 'heading',
                txt : 'Heading 1'
            },
            p : {
                _class : 'pgph',
                txt : ['paragraph1', 'paragraph2', 'paragraph3']
        }
    }
}
var html = jxh(obj);
console.log(html);
```
Output:
```
<div id="main-content" class="box-top">
  <h1 class="heading">Heading 1</h1>
  <p class="pgph">paragraph1</p>
  <p class="pgph">paragraph2</p>
  <p class="pgph">paragraph3</p>
</div>
```

### Attributes - Alternative Syntax

```js
var obj = {
        div : {
            _id : 'main-content',
            _attr : 'class="box-top"', // use generic _attr property

            h1 : {
                _attr : 'class="heading"',
                txt : 'Heading 1'
            },
            p : {
                _class : 'outer-pgph', // array outer
                txt : [
                    'paragraph1', 
                    {_class : 'inner-pgph', txt : 'paragraph2'}, // array inner
                    'paragraph3'
                ]
        }
    }
}
var html = jxh(obj);
console.log(html);
```
Output:
```
<div id="main-content" class="box-top">
  <h1 class="heading">Heading 1</h1>
  <p class="outer-pgph">paragraph1</p>
  <p class="inner-pgph">paragraph2</p>
  <p class="outer-pgph">paragraph3</p>
</div>
```

### Other Elements

```js
var obj = {
    meta$ : 'charset="utf-8"', // $ = empty element 
    meta$$ : 'charset="utf-8"', // $$ = self-closing element 
    div_h1_ : 'Heading 1', // quick nested elements
    div_span_p_ : ['paragraph1', 'paragraph2', 'paragraph3']
}
var html = jxh(obj);
console.log(html);
```
Output:
```
<meta charset="utf-8">
<meta charset="utf-8"/>
<div><h1>Heading 1</h1></div>
<div><span><p>paragraph1</p></span></div>
<div><span><p>paragraph2</p></span></div>
<div><span><p>paragraph3</p></span></div>
```

### Component Objects

```js
var obj = {
    $section1 : { // prefix with $ to parse inner-content only
        div : {
            h1 : 'Heading 1',
            p : ['paragraph1', 'paragraph2', 'paragraph3']
        }
    },
    $section2 : { // prefix with $ to parse inner-content only
        div : {
            h1 : 'Heading 2',
            p : ['paragraph1', 'paragraph2', 'paragraph3']
        }
    }
}
var html = jxh(obj);
console.log(html);
```
Output:
```
<div>
  <h1>Heading 1</h1>
  <p>paragraph1</p>
  <p>paragraph2</p>
  <p>paragraph3</p>
</div>
<div>
  <h1>Heading 2</h1>
  <p>paragraph1</p>
  <p>paragraph2</p>
  <p>paragraph3</p>
</div>
```

### Component Arrays

```js
var section1 = {
    div : {
        h2 : 'Section 1',
        p : ['paragraph1', 'paragraph2', 'paragraph3']
    }
}
var section2 = {
    div : {
        h2 : 'Section 2',
        p : ['paragraph1', 'paragraph2', 'paragraph3']
    }
}
var obj = {
    div : {
        div : {
            h1: 'Heading 1'
        },
        $subSections : [section1, section2]
    }
}
var html = jxh(obj);
console.log(html);
```
Output:
```
<div>
  <div>
    <h1>Heading 1</h1>
  </div>
  <div>
    <h2>Section 1</h2>
    <p>paragraph1</p>
    <p>paragraph2</p>
    <p>paragraph3</p>
  </div>
  <div>
    <h2>Section 2</h2>
    <p>paragraph1</p>
    <p>paragraph2</p>
    <p>paragraph3</p>
  </div>
</div>
```

### Array Arguments

```js
var section1 = {
    div : {
        h2 : 'Section 1',
        p : ['paragraph1', 'paragraph2', 'paragraph3']
    }
}
var section2 = {
    div : {
        h2 : 'Section 2',
        p : ['paragraph1', 'paragraph2', 'paragraph3']
    }
}
var html = jxh([section1, section2]); // jxh accepts array arguments
console.log(html);
```
Output:
```
<div>
  <h2>Section 1</h2>
  <p>paragraph1</p>
  <p>paragraph2</p>
  <p>paragraph3</p>
</div>
<div>
  <h2>Section 2</h2>
  <p>paragraph1</p>
  <p>paragraph2</p>
  <p>paragraph3</p>
</div>
```
